"""
Permissions include
u for upload
d for download
x for delete
Possible combinations are 'u', 'ud', 'ux', 'udx'
default permissions on new directory is 'ux'

"""
ALLOWED_PERMS = ['u', 'ud', 'ux', 'udx']
DEFAULT_PERMS = 'ux'

# user groups:
# hca-wrangler     s3 full access
# hca-contributor  hca-util bucket (ListBucket except top-level/root directory)

# Permissions for Object operations
#                       permissions        s3 operations
s3_permissions = {'u': 's3:PutObject',     # PUT Object, POST Object, Initiate Multipart Upload, Upload Part, Complete Multipart Upload, PUT Object - Copy
                  'd': 's3:GetObject',     # GET Object, HEAD Object, SELECT Object Content
                  'x': 's3:DeleteObject'}  # DELETE Object


def get_policy_statement_template():
    return {
        'Action': [],
        'Effect': 'Allow',
        'Resource': 'arn:aws:s3:::BUCKET_NAME/DIR_NAME/*',
        'Principal': {
            'AWS': [
                'arn:aws:iam::871979166454:user/HCAContributor'
            ]
        }
    }.copy()


def new_policy_statement(bucket, dir, perms=None):
    statement = get_policy_statement_template()
    # add permissions/actions
    if perms is None or perms not in ALLOWED_PERMS:
        perms = DEFAULT_PERMS
    for p in perms:
        statement['Action'].append(s3_permissions.get(p))
        res = statement['Resource']
        statement['Resource'] = res.replace('BUCKET_NAME', bucket).replace('DIR_NAME', dir)
    return statement



import json
from botocore.exceptions import ClientError
from hca_util.bucket_policy import new_policy_statement
from hca_util.common import gen_uuid
from hca_util.common import print_err


class CmdCreate:
    """
    user: wrangler only
    aws resource or client used in command - s3 client (put_object), s3 resource (BucketPolicy)
    """

    def __init__(self, aws, args):
        self.aws = aws
        self.args = args

    def run(self):

        if self.aws.is_contributor:
            return False, 'You don\'t have permission to use this command'

        project_name = self.args.n  # optional str, None
        perms = self.args.p  # optional str, default 'ux'

        # generate random uuid prefix for directory name
        dir_name = gen_uuid()

        try:

            metadata = {}
            if project_name:
                metadata['name'] = project_name
            metadata['perms'] = perms

            s3_client = self.aws.common_session.client('s3')
            s3_client.put_object(Bucket=self.aws.bucket_name, Key=(dir_name + '/'), Metadata=metadata)

            # get bucket policy
            s3_resource = self.aws.common_session.resource('s3')
            try:
                bucket_policy = s3_resource.BucketPolicy(self.aws.bucket_name)
                policy_str = bucket_policy.policy
            except ClientError:
                policy_str = ''

            if policy_str:
                policy_json = json.loads(policy_str)
            else:  # no bucket policy
                policy_json = json.loads('{ "Version": "2012-10-17", "Statement": [] }')

            # add new statement for dir to existing bucket policy
            new_statement = new_policy_statement(self.aws.bucket_name, dir_name, perms)
            policy_json['Statement'].append(new_statement)

            updated_policy = json.dumps(policy_json)

            bucket_policy.put(Policy=updated_policy)
            return True, 'Created ' + dir_name

        except Exception as e:
            print_err(e, 'create')



from hca_util.user_profile import profile_exists, get_profile, UserProfile
from hca_util.aws_client import Aws
from hca_util.command.config import CmdConfig
from hca_util.command.create import CmdCreate
from hca_util.command.select import CmdSelect
from hca_util.command.list import CmdList
from hca_util.command.dir import CmdDir
from hca_util.command.upload import CmdUpload
from hca_util.command.download import CmdDownload
from hca_util.command.delete import CmdDelete


class HcaCmd():
    """
    steps to perform before executing command
    if cmd is config, skip steps, run config
    else
        check user profile (default or specified via --profile)
        instantiate an aws client
        check valid credentials (via sts get caller identity)
        flag is_contributor
        get bucket name (from secret mgr)
    """

    def __init__(self, args):

        if args.command == 'config':
            success, msg = CmdConfig(args).run()
            print(msg)

        elif args.command == 'dir':
            success, msg = CmdDir.run()
            print(msg)

        elif args.command == 'clear':
            a = args.a  # clear all
            success, msg = CmdDir.clear(a)
            print(msg)

        else:

            if profile_exists(args.profile):
                self.user_profile = get_profile(args.profile)
                self.aws = Aws(self.user_profile)

                if self.aws.is_valid_credentials():
                    # print('Valid credentials')
                    try:
                        self.aws.get_bucket_name()
                        self.execute(args)

                    except:
                        print('Unable to get bucket')

                else:
                    print('Invalid credentials')

            else:
                print(f'Profile \'{args.profile}\' not found')

    def execute(self, args):
        if args.command == 'create':
            success, msg = CmdCreate(self.aws, args).run()
            print(msg)

        elif args.command == 'select':
            CmdSelect(self.aws, args).run()

        elif args.command == 'list':
            CmdList(self.aws, args).run()

        elif args.command == 'upload':
            CmdUpload(self.aws, args).run()

        elif args.command == 'download':
            CmdDownload(self.aws, args).run()

        elif args.command == 'delete':
            CmdDelete(self.aws, args).run()



from hca_util.local_state import set_selected_dir
from hca_util.common import print_err


class CmdSelect:
    """
    user: both wrangler and contributor
    aws resource or client used in command - s3 client (list_objects_v2)
    """

    def __init__(self, aws, args):
        self.aws = aws
        self.args = args

    def run(self):

        try:
            key = self.args.DIR if self.args.DIR.endswith('/') else f'{self.args.DIR}/'

            if self.aws.obj_exists(key):
                set_selected_dir(key)
                print('Selected ' + key)
            else:
                print("Directory does not exist")

        except Exception as e:
            print_err(e, 'select')



import os
from hca_util.local_state import get_selected_dir
from hca_util.common import print_err
from hca_util.file_transfer import FileTransfer, TransferProgress, transfer


"""
Uploading to Upload Service upload area
1. get upload creds from upload service api
2. upload via awscli or hca-util. set content-type accordingly
3. post fileUpload notification to upload service api
"""


class CmdUpload:
    """
    user: both wrangler and contributor
    aws resource or client used in command - s3 resource (Bucket().upload_file), s3 client list_objects_v2
    """

    def __init__(self, aws, args):
        self.aws = aws
        self.args = args

    def run(self):

        selected_dir = get_selected_dir()

        if not selected_dir:
            print('No directory selected')
            return

        try:
            # choice 1
            all_files = self.args.a  # optional bool

            fs = []
            if all_files:
                # upload files from current directory
                for f in os.listdir('.'):
                    # only files (not directories) and skip hidden files
                    if os.path.isfile(f) and not f.startswith('.'):
                        f_size = os.path.getsize(f)
                        fs.append(FileTransfer(key=f, size=f_size))
            else:

                # choice 2 upload specified list of files
                # optional list of <_io.TextIOWrapper name='f1' mode='r' encoding='UTF-8'>

                for f in self.args.f :
                    # argparse takes care of path expansion and check if file doesn't exist
                    f_size = os.path.getsize(f.name)
                    fs.append(FileTransfer(key=f.name, size=f_size))

            def upload(idx):
                try:
                    fname = fs[idx].key
                    key = selected_dir + os.path.basename(fname)

                    # creating a new session for each file upload/thread, as it's unclear whether they're
                    # thread-safe or not

                    sess = self.aws.new_session()

                    if not self.args.o and self.aws.obj_exists(key):
                        fs[idx].status = 'File exists. Use -o to overwrite.'
                        fs[idx].complete = True
                    else:
                        res = sess.resource('s3')
                        # upload_file automatically handles multipart uploads via the S3 Transfer Manager
                        # put_object maps to the low-level S3 API request, it does not handle multipart uploads
                        res.Bucket(self.aws.bucket_name).upload_file(Filename=fname, Key=key,
                                                                     Callback=TransferProgress(fs[idx]))
                except Exception as thread_ex:
                    fs[idx].status = 'Upload failed.'
                    fs[idx].complete = True

            print('Uploading...')

            transfer(upload, fs)

        except Exception as e:
            print_err(e, 'upload')



import json
from botocore.exceptions import ClientError
from hca_util.local_state import get_selected_dir
from hca_util.common import print_err
from hca_util.command.dir import CmdDir


class CmdDelete:
    """
    user: both wrangler and contributor, though contributor can't delete folder
    aws resource or client used in command - s3 resource (bucket.objects/ obj.delete)
    """

    def __init__(self, aws, args):
        self.aws = aws
        self.args = args

    def run(self):

        selected_dir = get_selected_dir()

        if not selected_dir:
            print('No directory selected')
            return

        try:
            s3_resource = self.aws.common_session.resource('s3')
            bucket = s3_resource.Bucket(self.aws.bucket_name)

            if self.args.d:  # delete dir
                if self.aws.is_contributor:
                    print('You don\'t have permission to use this command')
                    return

                confirm = input(f'Confirm delete {selected_dir}? Y/y to proceed: ')

                if confirm.lower() == 'y':
                    print('Deleting...')

                    for obj in bucket.objects.filter(Prefix=selected_dir):
                        print(obj.key)
                        obj.delete()

                    # delete bucket policy for HCAContributer-folder permissions
                    # only wrangler who has perms to set policy can do this
                    delete_dir_perms_from_bucket_policy(s3_resource, self.aws.bucket_name, selected_dir)

                    # clear selected dir
                    CmdDir.clear(False)
                return

            if self.args.a:  # delete all files
                print('Deleting...')
                for obj in bucket.objects.filter(Prefix=selected_dir):
                    # do not delete folder object
                    if obj.key == selected_dir:
                        continue
                    print(obj.key)
                    obj.delete()
                return

            if self.args.f:  # delete list of file(s)
                print('Deleting...')
                for f in self.args.f:
                    # you may have perm x but not d (to load or even do a head object)
                    # so use obj_exists

                    if self.aws.obj_exists(selected_dir + f):

                        obj = s3_resource.ObjectSummary(self.aws.bucket_name, selected_dir + f)
                        obj.delete()
                        print(selected_dir + f + '  Done.')
                    else:
                        print(selected_dir + f + '  File not found.')
                return

        except Exception as e:
            print_err(e, 'delete')


def delete_dir_perms_from_bucket_policy(s3_res, bucket_name, dir_name):
    try:
        bucket_policy = s3_res.BucketPolicy(bucket_name)
        policy_str = bucket_policy.policy
    except ClientError:
        policy_str = ''

    if policy_str:
        policy_json = json.loads(policy_str)
        changed = False
        for stmt in policy_json['Statement']:
            if dir_name in stmt['Resource']:
                policy_json['Statement'].remove(stmt)
                changed = True
        if changed:
            updated_policy = json.dumps(policy_json)
            bucket_policy.put(Policy=updated_policy)



from hca_util.local_state import get_selected_dir

from hca_util.common import print_err


class CmdList:
    """
    user: both wrangler and contributor
    aws resource or client used in command - s3 resource (bucket.objects, Object().metadata)
    """

    def __init__(self, aws, args):
        self.aws = aws
        self.args = args

    def run(self):

        if self.args.b:  # list all dirs in bucket
            if self.aws.is_contributor:
                print('You don\'t have permission to use this command')
                return
            try:
                s3_resource = self.aws.common_session.resource('s3')
                bucket = s3_resource.Bucket(self.aws.bucket_name)

                folder_count = 0
                for obj in bucket.objects.all():
                    k = obj.key
                    if k.endswith('/'):
                        print(k, end=' ')
                        obj_meta = obj.Object().metadata
                        if obj_meta:
                            p = ''
                            if 'perms' in obj_meta:
                                p = obj_meta.get('perms')
                            print(p.ljust(3), end=' ')
                            if 'name' in obj_meta:
                                n = obj_meta.get('name')
                                print(f'{n}' if n else '', end=' ')
                        print()
                        folder_count += 1

                print_count(folder_count)

            except Exception as e:
                print_err(e, 'list')

        else:  # list selected dir contents

            selected_dir = get_selected_dir()

            if not selected_dir:
                print('No directory selected')
                return

            try:
                selected_dir += '' if selected_dir.endswith('/') else '/'

                s3_resource = self.aws.common_session.resource('s3')
                bucket = s3_resource.Bucket(self.aws.bucket_name)

                file_count = 0
                for obj in bucket.objects.filter(Prefix=selected_dir):
                    k = obj.key
                    print(k)
                    if not k.endswith('/'):
                        file_count += 1
                print_count(file_count)

            except Exception as e:
                print_err(e, 'list')


def print_count(count):
    if count == 0:
        print('No item')
    elif count == 1:
        print('1 item')
    else:
        print(f'{count} items')



from hca_util.common import serialize, deserialize
from hca_util.settings import LOCAL_STATE_FILE


class LocalState:

    def __init__(self):
        self.selected_dir = None
        self.known_dirs = []
        # potential other local state vars
        self.tmp_access_key = None
        self.tmp_secret_key = None
        self.token = None

    def select_dir(self, dir_name):
        self.selected_dir = dir_name

        if dir_name not in self.known_dirs:
            self.known_dirs.append(dir_name)

    def unselect_dir(self):
        self.selected_dir = None

    def __str__(self):
        if self.selected_dir:
            s = f'Selected {self.selected_dir}'
        else:
            s = 'No directory selected'

        s += '\nKnown dirs:\n'
        known_dirs_minus_selected = [d for d in self.known_dirs if d != self.selected_dir]

        if known_dirs_minus_selected:
            s += '\n'.join(map(str, known_dirs_minus_selected))
        else:
            s += 'None'

        return s


def set_selected_dir(dir_name):
    obj = deserialize(LOCAL_STATE_FILE)
    if obj is None or not isinstance(obj, LocalState):
        obj = LocalState()
    obj.select_dir(dir_name)
    serialize(LOCAL_STATE_FILE, obj)


def get_local_state():

    obj = deserialize(LOCAL_STATE_FILE)
    if obj and isinstance(obj, LocalState):
        return obj
    return LocalState()


def set_local_state(obj):
    serialize(LOCAL_STATE_FILE, obj)


def get_selected_dir():
    obj = deserialize(LOCAL_STATE_FILE)
    if obj and isinstance(obj, LocalState):
        return obj.selected_dir
    return None



# __main__.py

import sys
import argparse
from hca_util.settings import DEFAULT_PROFILE, DEBUG_MODE
from hca_util.common import is_valid_project_name, is_valid_dir_name
from hca_util.hca_cmd import HcaCmd
from hca_util.bucket_policy import ALLOWED_PERMS, DEFAULT_PERMS


def valid_project_name(string):
    if not is_valid_project_name(string):
        msg = 'invalid - needs to be between 1-36 alphanumeric characters with no space'
        raise argparse.ArgumentTypeError(msg)
    return string


def valid_dir(string):
    if not is_valid_dir_name(string):
        msg = 'invalid - needs to be <uuid> or <uuid>/'
        raise argparse.ArgumentTypeError(msg)
    return string


def parse_args(args):
    parser = argparse.ArgumentParser(description='hca-util')

    cmd_parser = parser.add_subparsers(title='command', dest='command')
    cmd_parser.required = True

    parser_config = cmd_parser.add_parser('config', help='configure AWS credentials')
    parser_config.add_argument('ACCESS_KEY', help='AWS Access Key ID')
    parser_config.add_argument('SECRET_KEY', help='AWS Secret Access Key')

    parser_create = cmd_parser.add_parser('create', help='create an upload directory (authorised user only)')
    parser_create.add_argument('-n', metavar='name', help='optional project name for new directory', type=valid_project_name)
    parser_create.add_argument('-p', choices=ALLOWED_PERMS, default=DEFAULT_PERMS, help=f'allowed actions ('
                                                                                        f'permissions) on new '
                                                                                        f'directory. u for upload, '
                                                                                        f'x for delete and d for '
                                                                                        f'download. Default is '
                                                                                        f'{DEFAULT_PERMS}')

    parser_select = cmd_parser.add_parser('select', help='select active directory')
    parser_select.add_argument('DIR', help='directory uuid', type=valid_dir)

    parser_dir = cmd_parser.add_parser('dir', help='display active (selected) directory')

    parser_clear = cmd_parser.add_parser('clear', help='clear current selection')
    parser_clear.add_argument('-a', action='store_true', help='clear all - selection and known dirs')

    parser_list = cmd_parser.add_parser('list', help='list contents of selected directory')
    parser_list.add_argument('-b', action='store_true', help='list all directories in bucket (authorised user only)')

    parser_upload = cmd_parser.add_parser('upload', help='upload files to selected directory')
    group_upload = parser_upload.add_mutually_exclusive_group(required=True)

    group_upload.add_argument('-a', action='store_true', help='upload all files from current user directory')
    group_upload.add_argument('-f', metavar='file', nargs='+', help='upload specified file(s)', type=argparse.FileType('r'))
    parser_upload.add_argument('-o', action='store_true', help='overwrite files with same names')

    parser_download = cmd_parser.add_parser('download', help='download files from selected directory')
    group_download = parser_download.add_mutually_exclusive_group(required=True)

    group_download.add_argument('-a', action='store_true', help='download all files from selected directory')
    group_download.add_argument('-f', metavar='file', nargs='+', help='download specified file(s) only')

    parser_delete = cmd_parser.add_parser('delete', help='delete files from selected directory')
    group_delete = parser_delete.add_mutually_exclusive_group(required=True)

    group_delete.add_argument('-a', action='store_true', help='delete all files from selected directory')
    group_delete.add_argument('-f', metavar='file', nargs='+', help='delete specified file(s) only')
    group_delete.add_argument('-d', action='store_true', help='delete directory and contents (authorised user only)')

    ps = [parser]
    if DEBUG_MODE:
        ps = [parser, parser_config, parser_create, parser_select, parser_list, parser_upload, parser_download, parser_delete]

    for p in ps:
        p.add_argument(
            '--profile',
            help=f'use PROFILE instead of default \'{DEFAULT_PROFILE}\' profile',
            default=DEFAULT_PROFILE
        )

    # parser.add_argument(
    #     '--region',
    #     help=f'use REGION instead of default \'{DEFAULT_REGION}\' region',
    #     default=DEFAULT_REGION
    # )

    return parser.parse_args(args)


def main():
    parsed_args = parse_args(sys.argv[1:])
    HcaCmd(parsed_args)


if __name__ == '__main__':
    main()



from hca_util.local_state import get_local_state, set_local_state, LocalState


class CmdDir:
    """
    user: both wrangler and contributor
    aws resource or client used in command - none, all local operations.
    """

    @staticmethod
    def run():
        local_state = get_local_state()
        return True, str(local_state)

    @staticmethod
    def clear(a):
        if a:  # clear all
            local_state = LocalState()  # create a new empty local state obj
            set_local_state(local_state)
            return True, 'All cleared'
        else:
            local_state = get_local_state()
            local_state.unselect_dir()
            set_local_state(local_state)
            return True, 'Selection cleared'



import boto3
import json
from hca_util.settings import AWS_SECRET_NAME, IAM_USER_CONTRIBUTOR


class Aws:

    def __init__(self, user_profile):
        self.user_profile = user_profile
        self.common_session = self.new_session()
        self.is_contributor = False
        self.bucket_name = None

    def new_session(self):
        return boto3.Session(region_name=self.user_profile.region,
                             aws_access_key_id=self.user_profile.access_key,
                             aws_secret_access_key=self.user_profile.secret_key)

    def is_valid_credentials(self):
        """
        Validate user config/credentials by making a get_caller_identity aws api call
        :return:
        """
        sts = self.common_session.client('sts')

        try:
            resp = sts.get_caller_identity()
            arn = resp.get('Arn')
            if arn.endswith(f'user/{IAM_USER_CONTRIBUTOR}'):
                self.is_contributor = True
            return True
        except:
            return False

    def get_bucket_name(self):
        """
        Get bucket name from aws secrets
        :return:
        """
        # access policy can't be attached to a secret
        # GetSecretValue action should be allowed for user
        secret_mgr = self.common_session.client('secretsmanager')

        resp = secret_mgr.get_secret_value(SecretId=AWS_SECRET_NAME)
        secret_str = resp['SecretString']
        self.bucket_name = json.loads(secret_str)['s3-bucket']
        return self.bucket_name

    def obj_exists(self, key):
        """
        return true if key exists, else false
        A folder/directory is an s3 object with key <uuid>/
        Note: s3://my-bucket/folder != s3://my-bucket/folder/
        Refer to https://www.peterbe.com/plog/fastest-way-to-find-out-if-a-file-exists-in-s3
        for comparison between client.list_objects_v2 and client.head_object to make this check.
        Also check https://stackoverflow.com/questions/33842944/check-if-a-key-exists-in-a-bucket-in-s3-using-boto3
        which suggests using Object.load() - which does a HEAD request, however, HCAContributor doesn't have
        s3:GetObject permission by default, so this will fail for them.
        """
        response = self.new_session().client('s3').list_objects_v2(
            Bucket=self.bucket_name,
            Prefix=key,
        )
        for obj in response.get('Contents', []):
            if obj['Key'] == key:
                return True
        return False



# from multiprocessing.dummy import Pool
import threading
from time import sleep


class TransferProgress(object):

    def __init__(self, file_transfer):
        self._file_transfer = file_transfer
        self._lock = threading.Lock()

    def __call__(self, bytes_amount):

        with self._lock:
            self._file_transfer.seen_so_far += bytes_amount
            percentage = (self._file_transfer.seen_so_far / self._file_transfer.size) * 100

            if percentage == 100.0:
                self._file_transfer.complete = True

            self._file_transfer.status = f'({percentage:.2f}%)'


class FileTransfer:
    def __init__(self, key, size=0, seen_so_far=0, status='', complete=False):
        self.key = key
        self.size = size
        self.seen_so_far = seen_so_far
        self.status = status
        self.complete = complete

    def __str__(self):
        return f'FileTransfer (key={self.key}, size={self.size}, seen_so_far={self.seen_so_far}, status={self.status}, complete={self.complete}) '


# with Pool(12) as p:
#    p.map(lambda f: self.upload(f), fs)
#    print('Done.')

# using a thread per file upload instead of threadpool as they are cheap

def transfer(t, fs):
    for i in range(len(fs)):
        if not fs[i].complete:
            threading.Thread(target=t, args=(i,)).start()

    # print initial transfer progress
    for f in fs:
        print(f'{f.key}  {f.seen_so_far} / {f.size}  {f.status}')

    while True:
        if [t for t in fs if not t.complete]:
            sleep(1)  # 1 sec
            print(f'\033[{len(fs) + 1}A\r')  # go back to start of first progress_list item
            for f in fs:
                print(f'{f.key}  {f.seen_so_far} / {f.size}  {f.status}')
        else:
            break



from hca_util.user_profile import set_profile, profile_exists, get_profile
from hca_util.settings import DEFAULT_PROFILE, DEFAULT_REGION
from hca_util.aws_client import Aws
from hca_util.common import print_err


class CmdConfig:
    """
    user: both wrangler and contributor
    aws resource or client used in command - sts (to check valid credentials).
    """

    def __init__(self, args):
        self.args = args

    def run(self):

        try:
            set_profile(DEFAULT_PROFILE, DEFAULT_REGION, self.args.ACCESS_KEY, self.args.SECRET_KEY)

            # check new profile
            if profile_exists(DEFAULT_PROFILE):
                user_profile = get_profile(DEFAULT_PROFILE)
                aws = Aws(user_profile)

                if aws.is_valid_credentials():
                    return True, 'Valid credentials'
                else:
                    return False, 'Invalid credentials'
            else:
                return False, 'Error setting profile'

        except Exception as e:
            print_err(e, 'config')



import os
import pathlib
from setuptools import setup

# directory containing this file
HERE = pathlib.Path(__file__).parent

# text of the README file
README = (HERE / 'README.md').read_text()

# install requirements
INSTALL_REQS = [line.rstrip() for line in open(os.path.join(os.path.dirname(__file__), 'requirements.txt'))]

# This call to setup() does all the work
setup(
    # dashes are ok in repo and PyPI dist names but not in package (i.e. directory) and
    # module (.py file) names. can't do import xyz-abc
    name='hca-util',
    version='0.1.4',
    description='CLI tool for file transfer (upload and download) to/from AWS S3.',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/ebi-ait/hca-util',
    author='hca-ingest-dev',
    author_email='prabhat@ebi.ac.uk',
    license='Apache License',
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    platforms=['MacOS X', 'Posix'],
    packages=['hca_util', 'hca_util.command'],
    include_package_data=True,
    install_requires=INSTALL_REQS,
    entry_points={
        'console_scripts': [
            'hca-util=hca_util.__main__:main',
        ]
    },
)



from pathlib import Path

# when true, displays exception details; otherwise user-friendly error message
DEBUG_MODE = True

# user home directory
USER_HOME = str(Path.home())

# aws config and credentials files
AWS_CONFIG_FILE = USER_HOME + '/.aws/config'
AWS_CREDENTIALS_FILE = USER_HOME + '/.aws/credentials'

AWS_SECRET_NAME = 'hca/util/secret'

# default profile uses credentials from [DEFAULT_PROFILE] section of AWS_CREDENTIALS_FILE
# and config from [profile DEFAULT_PROFILE] section of AWS_CONFIG_FILE
DEFAULT_PROFILE = 'hca-util'
DEFAULT_REGION = 'us-east-1'

# local state for user
LOCAL_STATE_FILE = USER_HOME + '/.hca-util'

# contributor IAM user name
IAM_USER_CONTRIBUTOR = 'HCAContributor'
